# pyutiltools

[![forthebadge made-with-python](http://ForTheBadge.com/images/badges/made-with-python.svg)](https://www.python.org/)                 
[![Python 3.10](https://img.shields.io/badge/python-3.10-blue.svg)](https://www.python.org/downloads/)   

## Functionality of the pyutiltools

- Train Deep Learning Models

## Documentation 
- [Click here for full documentation](https://www.drateendrajha.com/blog/tags/pyutiltools)


## Functions
- Random mouse movement 
```
move_random_mouse(time_out_minute = 1, stop_key = 'q', x = 1000, y=300)
```

